@@ -233,7 +233,7 @@ function getMeasurementSystem() {
 }
 
 /**
- * Get the higest priority bare lange currently in use.
+ * Get the highest priority bare lange currently in use.
  */
 function getLanguage() {
     let locale = GLib.get_language_names()[0];
@@ -254,6 +254,22 @@ function getAccuracyDescription(accuracy) {
     }
 }
 
+function loadAvatar(pixbuf, size) {
+    let width = pixbuf.get_width();
+    let height = pixbuf.get_height();
+    let croppedThumbnail;
+
+    if (width > height) {
+        let x = (width - height) / 2;
+        croppedThumbnail = pixbuf.new_subpixbuf(x, 0, height, height);
+    } else {
+        let y = (height - width) / 2;
+        croppedThumbnail = pixbuf.new_subpixbuf(0, y, width, width);
+    }
+
+    return croppedThumbnail.scale_simple(size, size, GdkPixbuf.InterpType.BILINEAR);
+}
+
 function load_icon(icon, size, loadCompleteCallback) {
     if (icon instanceof Gio.FileIcon || icon instanceof Gio.BytesIcon) {
         _load_icon(icon, loadCompleteCallback);
@@ -332,7 +348,7 @@ function prettyTime(time) {
         return _("%s h").format(hoursStr);
     } else if (hours > 0) {
         /* Translators: this is a duration with hours and minutes parts
-         * using abbreviations for hours and minutes, correspoding to 'h'
+         * using abbreviations for hours and minutes, corresponding to 'h'
          * and 'min' in English. The minutes has appropriate plural variations
          */
         return ngettext("%s h %s min", "%s h %s min",
@@ -442,3 +458,19 @@ function getCountryCodeForCoordinates(lat, lon) {
     return location.get_country();
 }
 
+/* Determines whether a URI is valid and its scheme is HTTP or HTTPS. */
+function isValidWebsite(website) {
+    try {
+        GLib.Uri.is_valid(website, GLib.UriFlags.NONE);
+    } catch(e) {
+        return false;
+    }
+    return website.startsWith("http://") || website.startsWith("https://");
+}
+
+/* Return string with first character in upper case according the rules
+ * determined by the current locale
+ */
+function firstToLocaleUpperCase(str) {
+    return str[0].toLocaleUpperCase() + str.substring(1);
+}
